California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 003 - AUTHORIZES BONDS TO FUND PROJECTS FOR WATER SUPPLY AND QUALITY, WATERSHED, FISH, WILDLIFE, WATER CONVEYANCE, AND GROUNDWATER SUSTAINABILITY AND STORAGE. INITIATIVE STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1280428 | AGRICULTURAL AND DAIRY COMMUNITY FOR SAFE DRINKING WATER AND A RELIABLE WATER SUPPLY, YES ON PROPOSITION 3 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1397965 | CALIFORNIANS FOR SAFE DRINKING WATER AND A CLEAN AND RELIABLE WATER SUPPLY IN SUPPORT OF PROPOSITION 3 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1399067 | CALIFORNIA WATERFOWL ASSOCIATION FOR SAFE DRINKING WATER AND A CLEAN AND RELIABLE WATER SUPPLY ( NON-PROFIT 501 (C) (3) ), YES ON PROPOSITION 3 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1401925 | AMERICAN PISTACHIO GROWERS (NON-PROFIT 501 (C) (6) ) , CALIFORNIANS FOR SAFE DRINKING WATER AND A CLEAN AND RELIABLE WATER SUPPLY IN SUPPORT OF PROP 3 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1397882 | NORTHERN CALIFORNIA WATER ASSOCIATION FOR PROPOSITION 3 | SUPPORT